# ResourceCollectionTenantResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**item_type** | **str** |  | [optional] 
**total_results** | **int** |  | [optional] 
**items_per_page** | **int** |  | [optional] 
**number_of_pages** | **int** |  | [optional] 
**last_page_number** | **int** |  | [optional] 
**items** | [**list[TenantResource]**](TenantResource.md) |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


